@@ -752,7 +752,7 @@ class ImageWindow(toolsQtWidget.MWidget):
         full, short, ext = self.extractNames([self.imageFileName])
         self.ui.imageFileName.setText(short)
 
-        with fits.open(self.imageFileName, mode='update') as fitsHandle:
+        with fits.open(self.imageFileName) as fitsHandle:
             self.image = fitsHandle[0].data
             self.header = fitsHandle[0].header
 
@@ -892,7 +892,7 @@ class ImageWindow(toolsQtWidget.MWidget):
         :return: True for test purpose
         """
         self.app.camera.abort()
-        # for disconnection we have to split which slots were connected to
+        # for disconnection, we have to split which slots were connected to
         # disable the right ones
         if self.deviceStat['expose']:
             self.app.camera.signals.saved.disconnect(self.exposeImageDone)
