@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -33,6 +33,7 @@ from astropy.utils import data
 
 # local import
 from base.loggerMW import setCustomLoggingLevel
+from base.packageConfig import checkAutomation
 
 
 class SettMisc(object):
@@ -48,6 +49,9 @@ class SettMisc(object):
         self.ui.loglevelTrace.clicked.connect(self.setLoggingLevel)
         self.ui.loglevelDebug.clicked.connect(self.setLoggingLevel)
         self.ui.loglevelStandard.clicked.connect(self.setLoggingLevel)
+        self.ui.automateSlow.clicked.connect(self.setAutomationSpeed)
+        self.ui.automateFast.clicked.connect(self.setAutomationSpeed)
+        self.ui.automateNormal.clicked.connect(self.setAutomationSpeed)
         self.ui.isOnline.clicked.connect(self.setWeatherOnline)
         self.ui.isOnline.clicked.connect(self.setupIERS)
         self.ui.versionBeta.clicked.connect(self.showUpdates)
@@ -77,6 +81,9 @@ class SettMisc(object):
         self.ui.loglevelDebug.setChecked(config.get('loglevelDebug', False))
         self.ui.loglevelStandard.setChecked(config.get('loglevelStandard', True))
         self.ui.isOnline.setChecked(config.get('isOnline', False))
+        self.ui.automateFast.setChecked(config.get('automateFast', False))
+        self.ui.automateNormal.setChecked(config.get('automateSlow', True))
+        self.ui.automateSlow.setChecked(config.get('automateSlow', True))
         self.ui.syncNotTracking.setChecked(config.get('syncNotTracking', True))
         self.ui.syncTimePC2Mount.setChecked(config.get('syncTimePC2Mount', False))
         self.ui.clockSync.setChecked(config.get('clockSync', False))
@@ -89,6 +96,9 @@ class SettMisc(object):
         self.ui.soundImageSaved.setCurrentIndex(config.get('soundImageSaved', 0))
         self.ui.soundImageSolved.setCurrentIndex(config.get('soundImageSolved', 0))
 
+        isWindows = platform.system() == 'Windows'
+        self.ui.automateGroup.setVisible(isWindows)
+        self.setAutomationSpeed()
         self.toggleClockSync()
         self.setWeatherOnline()
         self.setupIERS()
@@ -104,6 +114,9 @@ class SettMisc(object):
         config['loglevelTrace'] = self.ui.loglevelTrace.isChecked()
         config['loglevelDebug'] = self.ui.loglevelDebug.isChecked()
         config['loglevelStandard'] = self.ui.loglevelStandard.isChecked()
+        config['automateFast'] = self.ui.automateFast.isChecked()
+        config['automateNormal'] = self.ui.automateNormal.isChecked()
+        config['automateSlow'] = self.ui.automateSlow.isChecked()
         config['isOnline'] = self.ui.isOnline.isChecked()
         config['syncNotTracking'] = self.ui.syncNotTracking.isChecked()
         config['syncTimePC2Mount'] = self.ui.syncTimePC2Mount.isChecked()
@@ -116,7 +129,6 @@ class SettMisc(object):
         config['soundModelingFinished'] = self.ui.soundModelingFinished.currentIndex()
         config['soundImageSaved'] = self.ui.soundImageSaved.currentIndex()
         config['soundImageSolved'] = self.ui.soundImageSolved.currentIndex()
-
         return True
 
     def setWeatherOnline(self):
@@ -444,3 +456,14 @@ class SettMisc(object):
         isVirtual = self.ui.activateVirtualStop.isChecked()
         self.ui.statusTime.setEnabled(not isVirtual)
         return True
+
+    def setAutomationSpeed(self):
+        """
+        :return:
+        """
+        if not checkAutomation():
+            return False
+
+        self.app.automation.automateFast = self.ui.automateFast.isChecked()
+        self.app.automation.automateSlow = self.ui.automateSlow.isChecked()
+        return True
