@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -106,6 +106,8 @@ class AutomateWindows(QObject):
         self.getAppSettings('10micron')
         self.updater = None
         self.actualWorkDir = os.getcwd()
+        self.automateSlow = False
+        self.automateFast = False
 
     @staticmethod
     def getRegistryPath():
@@ -255,7 +257,9 @@ class AutomateWindows(QObject):
         :return:
         """
         self.updater = Application(backend='uia')
-        if platform.architecture()[0] == '64bit':
+        if self.automateFast:
+            Timings.fast()
+        elif self.automateSlow:
             Timings.slow()
 
         try:
