@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 #
 # Licence APL2.0
 #
@@ -53,8 +53,12 @@ class CameraAlpaca(AlpacaClass, CameraSupport):
         self.getAndStoreAlpacaProperty('pixelsizey', 'CCD_INFO.CCD_PIXEL_SIZE_Y')
         self.getAndStoreAlpacaProperty('maxbinx', 'CCD_BINNING.HOR_BIN_MAX')
         self.getAndStoreAlpacaProperty('maxbiny', 'CCD_BINNING.VERT_BIN_MAX')
-        self.getAndStoreAlpacaProperty('gainmax', 'CCD_INFO.GAIN_MAX')
-        self.getAndStoreAlpacaProperty('gainmin', 'CCD_INFO.GAIN_MIN')
+        self.getAndStoreAlpacaProperty('gainmax', 'CCD_GAIN.GAIN_MAX')
+        self.getAndStoreAlpacaProperty('gainmin', 'CCD_GAIN.GAIN_MIN')
+        self.getAndStoreAlpacaProperty('gains', 'CCD_GAIN.GAIN_LIST')
+        self.getAndStoreAlpacaProperty('offsetmax', 'CCD_OFFSET.OFFSET_MAX')
+        self.getAndStoreAlpacaProperty('offsetmin', 'CCD_OFFSET.OFFSET_MIN')
+        self.getAndStoreAlpacaProperty('offsets', 'CCD_OFFSET.OFFSET_LIST')
         self.getAndStoreAlpacaProperty('startx', 'CCD_FRAME.X')
         self.getAndStoreAlpacaProperty('starty', 'CCD_FRAME.Y')
         self.log.debug(f'Initial data: {self.data}')
@@ -81,8 +85,6 @@ class CameraAlpaca(AlpacaClass, CameraSupport):
 
     def sendDownloadMode(self, fastReadout=False):
         """
-        setDownloadMode sets the readout speed of the camera
-
         :return: success
         """
         canFast = self.data.get('CAN_FAST', False)
@@ -93,7 +95,6 @@ class CameraAlpaca(AlpacaClass, CameraSupport):
 
         quality = 'High' if self.data.get('READOUT_QUALITY.QUALITY_HIGH', True) else 'Low'
         self.log.debug(f'Camera has readout quality entry: {quality}')
-
         return True
 
     def workerExpose(self,
@@ -125,7 +126,7 @@ class CameraAlpaca(AlpacaClass, CameraSupport):
         self.setAlpacaProperty('startx', StartX=int(posX / binning))
         self.setAlpacaProperty('starty', StartY=int(posY / binning))
         self.setAlpacaProperty('numx', NumX=int(width / binning))
-        self.setAlpacaProperty('numy', NumX=int(width / binning))
+        self.setAlpacaProperty('numy', NumY=int(height / binning))
 
         self.setAlpacaProperty('startexposure', Duration=expTime, Light=True)
         self.waitExposed(self.getAlpacaProperty, 'imageready', expTime)
@@ -146,11 +147,15 @@ class CameraAlpaca(AlpacaClass, CameraSupport):
                width=1,
                height=1,
                focalLength=1,
+               ra=None,
+               dec=None,
                ):
         """
 
         :return: success
         """
+        self.raJ2000 = ra
+        self.decJ2000 = dec
         self.abortExpose = False
         worker = Worker(self.workerExpose,
                         imagePath=imagePath,
@@ -169,10 +174,12 @@ class CameraAlpaca(AlpacaClass, CameraSupport):
         """
         :return: success
         """
+        self.raJ2000 = None
+        self.decJ2000 = None
+        self.abortExpose = True
         if not self.deviceConnected:
             return False
 
-        self.abortExpose = True
         canAbort = self.data.get('CAN_ABORT', False)
         if not canAbort:
             return False
