@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -55,7 +55,7 @@ class Dome:
             self.run['ascom'] = DomeAscom(self.app, self.signals, self.data)
 
         for fw in self.run:
-            self.defaultConfig['frameworks'].update(self.run[fw].defaultConfig)
+            self.defaultConfig['frameworks'].update({fw: self.run[fw].defaultConfig})
 
         self.useGeometry = False
         self.useDynamicFollowing = False
@@ -116,13 +116,13 @@ class Dome:
         if self.isSlewing:
             self.signals.message.emit('slewing')
             self.counterStartSlewing = -1
-            if not self.data.get('Slewing', True):
+            if not self.data.get('Slewing'):
                 self.isSlewing = False
                 self.signals.message.emit('wait settle')
                 self.settlingWait.start(self.settlingTime * 1000)
 
         else:
-            if self.data.get('Slewing', True):
+            if self.data.get('Slewing'):
                 self.log.debug('Slewing start by signal')
                 self.isSlewing = True
 
