@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -88,6 +88,7 @@ class Connection(object):
                 ':TLESCK', ':TROFFADD', ':TROFFCLR', ':TROFFGET', ':TROFFSET',
                 ':TRNEW', ':TRADD', ':TRP', ':TRREPLAY',
                 ':U2',
+                ':WSG', ':WSP', ':WST', ':WSH', ':WSD', ':WSS',
                 ':delalig', ':delalst',
                 ':endalig',
                 ':getain', ':getalp', ':getalst',
@@ -95,7 +96,6 @@ class Connection(object):
                 ':modelcnt', ':modeldel0', ':modelld0', ':modelnam',
                 ':modelsv0',
                 ':newalig', ':newalpt',
-                ':WSG', ':WSP', ':WST', ':WSH', ':WSD', ':WSS',
                 ':shutdown',
                 ]
 
@@ -106,11 +106,14 @@ class Connection(object):
                  ':Q', ':Qe', ':Qn', ':Qs', ':Qw',
                  ':RC', ':Rc', ':RG', ':RM', ':RS', ':RT0', ':RT1', ':RT2',
                  ':RT9',
-                 ':SDAr', ':STOP',
+                 ':SDAr', ':STOP', ':Suaf',
                  ':U2',
-                 ':hP', ':Suaf',
+                 ':hP',
                  ]
 
+    # Command list for commands which don't reply anything, but give a parameter
+    COMMAND_P = [':RC', ':Rc', ':RG', ':Suaf']
+
     # Command list for commands which have a response, but have no end mark
     # mostly these commands response value of '0' or '1'
     COMMAND_B = [':FLIP', ':shutdown', ':GREF', ':Guaf',
@@ -165,7 +168,7 @@ class Connection(object):
         data show be received.
 
         the command slots will be sorted in reverse order to ensure that longer
-        commands with the same leading characters will be tested first. otherwise
+        commands with the same leading characters will be tested first. otherwise,
         the test will be ended before testing al commands.
 
         :param commandString:       string sent to the mount
@@ -181,7 +184,7 @@ class Connection(object):
             foundCOMMAND_A = False
             for key in sorted(self.COMMAND_A, reverse=True):
                 if command.startswith(key):
-                    if key == ':Q':
+                    if len(command) != len(key) and key not in self.COMMAND_P:
                         continue
                     foundCOMMAND_A = True
                     break
